@@ -7,7 +7,7 @@ use File::Basename;
 use File::Spec;
 use File::Glob;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 # some class data
 our $Theme = 'foo'; # default theme
@@ -125,6 +125,9 @@ sub load_data {
         }
     }
 
+    # avoid leaving all the DATA handles open
+    close $fh;
+
     # clean up the items
     for( @items, $item ) {
         $$_ =~ s/\A\s*//;
